public inbox for passt-dev@passt.top
 help / color / mirror / code / Atom feed
From: Laurent Vivier <lvivier@redhat.com>
To: passt-dev@passt.top
Cc: Laurent Vivier <lvivier@redhat.com>,
	David Gibson <david@gibson.dropbear.id.au>
Subject: [PATCH v2 11/13] vu_common: Accept explicit iovec count per element in vu_init_elem()
Date: Mon,  9 Mar 2026 10:47:42 +0100	[thread overview]
Message-ID: <20260309094744.1907754-12-lvivier@redhat.com> (raw)
In-Reply-To: <20260309094744.1907754-1-lvivier@redhat.com>

Extend vu_init_elem() to accept an iov_per_elem parameter specifying
how many iovec entries to assign to each virtqueue element. The iov
array is now strided by iov_per_elem rather than 1.

Update all callers to pass 1, preserving existing behavior.

No functional change.

Signed-off-by: Laurent Vivier <lvivier@redhat.com>
Reviewed-by: David Gibson <david@gibson.dropbear.id.au>
---
 tcp_vu.c    |  2 +-
 udp_vu.c    |  2 +-
 vu_common.c | 19 ++++++++++---------
 vu_common.h |  2 +-
 4 files changed, 13 insertions(+), 12 deletions(-)

diff --git a/tcp_vu.c b/tcp_vu.c
index 1916c703a125..c0e4589f8193 100644
--- a/tcp_vu.c
+++ b/tcp_vu.c
@@ -211,7 +211,7 @@ static ssize_t tcp_vu_sock_recv(const struct ctx *c, struct vu_virtq *vq,
 
 	hdrlen = tcp_vu_hdrlen(v6);
 
-	vu_init_elem(elem, &iov_vu[DISCARD_IOV_NUM], ARRAY_SIZE(elem));
+	vu_init_elem(elem, &iov_vu[DISCARD_IOV_NUM], ARRAY_SIZE(elem), 1);
 
 	elem_cnt = 0;
 	*head_cnt = 0;
diff --git a/udp_vu.c b/udp_vu.c
index 414750ff742a..cb5274aa1d81 100644
--- a/udp_vu.c
+++ b/udp_vu.c
@@ -214,7 +214,7 @@ void udp_vu_sock_to_tap(const struct ctx *c, int s, int n, flow_sidx_t tosidx)
 		size_t iov_cnt;
 		ssize_t dlen;
 
-		vu_init_elem(elem, iov_vu, ARRAY_SIZE(elem));
+		vu_init_elem(elem, iov_vu, ARRAY_SIZE(elem), 1);
 
 		elem_cnt = vu_collect(vdev, vq, elem, ARRAY_SIZE(elem),
 				      IP_MAX_MTU + ETH_HLEN + VNET_HLEN, NULL);
diff --git a/vu_common.h b/vu_common.h
index 0d4ccdceab69..c47e06885e3f 100644
--- a/vu_common.h
+++ b/vu_common.h
@@ -54,7 +54,7 @@ static inline void vu_set_element(struct vu_virtq_element *elem,
 }
 
 void vu_init_elem(struct vu_virtq_element *elem, struct iovec *iov,
-		  int elem_cnt);
+		  int elem_cnt, int iov_per_elem);
 int vu_collect(const struct vu_dev *vdev, struct vu_virtq *vq,
 	       struct vu_virtq_element *elem, int max_elem, size_t size,
 	       size_t *collected);
diff --git a/vu_common.c b/vu_common.c
index 12746db066c4..94bd8d789a91 100644
--- a/vu_common.c
+++ b/vu_common.c
@@ -54,18 +54,19 @@ int vu_packet_check_range(struct vdev_memory *memory,
 }
 
 /**
  * vu_init_elem() - initialize an array of virtqueue elements with 1 iov in each
  * @elem:	Array of virtqueue elements to initialize
  * @iov:	Array of iovec to assign to virtqueue element
  * @elem_cnt:	Number of virtqueue element
  */
 void vu_init_elem(struct vu_virtq_element *elem, struct iovec *iov,
-		  int elem_cnt)
+		  int elem_cnt, int iov_per_elem)
 {
-	int i;
+	int i, j;
 
-	for (i = 0; i < elem_cnt; i++)
-		vu_set_element(&elem[i], 0, NULL, 1, &iov[i]);
+	for (i = 0, j = 0; i < elem_cnt; i++, j += iov_per_elem)
+		vu_set_element(&elem[i], 0, NULL, iov_per_elem, &iov[j]);
 }
 
 /**
@@ -287,7 +288,7 @@ int vu_send_single(const struct ctx *c, const void *buf, size_t size)
 		return -1;
 	}
 
-	vu_init_elem(elem, in_sg, ARRAY_SIZE(elem));
+	vu_init_elem(elem, in_sg, ARRAY_SIZE(elem), 1);
 
 	size += VNET_HLEN;
 	elem_cnt = vu_collect(vdev, vq, elem, ARRAY_SIZE(elem), size, &total);
@@ -54,18 +54,19 @@ int vu_packet_check_range(struct vdev_memory *memory,
 
 /**
- * vu_init_elem() - initialize an array of virtqueue elements with 1 iov in each
- * @elem:	Array of virtqueue elements to initialize
- * @iov:	Array of iovec to assign to virtqueue element
- * @elem_cnt:	Number of virtqueue element
+ * vu_init_elem() - Initialize an array of virtqueue elements
+ * @elem:	  Array of virtqueue elements to initialize
+ * @iov:	  Array of iovecs to assign to virtqueue elements
+ * @elem_cnt:	  Number of virtqueue elements
+ * @iov_per_elem: Number of iovecs per element
  */
 void vu_init_elem(struct vu_virtq_element *elem, struct iovec *iov,
-- 
2.53.0


  parent reply	other threads:[~2026-03-09  9:48 UTC|newest]

Thread overview: 14+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-03-09  9:47 [PATCH v2 00/13] vhost-user,udp: Handle multiple iovec entries per virtqueue element Laurent Vivier
2026-03-09  9:47 ` [PATCH v2 01/13] iov: Add iov_truncate() helper and use it in vu handlers Laurent Vivier
2026-03-09  9:47 ` [PATCH v2 02/13] vhost-user: Centralise 802.3 frame padding in vu_collect() and vu_flush() Laurent Vivier
2026-03-09  9:47 ` [PATCH v2 03/13] vhost-user: Use ARRAY_SIZE(elem) instead of VIRTQUEUE_MAX_SIZE Laurent Vivier
2026-03-09  9:47 ` [PATCH v2 04/13] udp_vu: Use iov_tail to manage virtqueue buffers Laurent Vivier
2026-03-09  9:47 ` [PATCH v2 05/13] udp_vu: Move virtqueue management from udp_vu_sock_recv() to its caller Laurent Vivier
2026-03-09  9:47 ` [PATCH v2 06/13] iov: Add IOV_PUT_HEADER() to write header data back to iov_tail Laurent Vivier
2026-03-09  9:47 ` [PATCH v2 07/13] udp: Pass iov_tail to udp_update_hdr4()/udp_update_hdr6() Laurent Vivier
2026-03-09  9:47 ` [PATCH v2 08/13] udp_vu: Use iov_tail in udp_vu_prepare() Laurent Vivier
2026-03-09  9:47 ` [PATCH v2 09/13] vu_common: Pass iov_tail to vu_set_vnethdr() Laurent Vivier
2026-03-09  9:47 ` [PATCH v2 10/13] vu_common: Accept explicit iovec counts in vu_set_element() Laurent Vivier
2026-03-09  9:47 ` Laurent Vivier [this message]
2026-03-09  9:47 ` [PATCH v2 12/13] vu_common: Prepare to use multibuffer with guest RX Laurent Vivier
2026-03-09  9:47 ` [PATCH v2 13/13] vhost-user,udp: Use 2 iovec entries per element Laurent Vivier

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260309094744.1907754-12-lvivier@redhat.com \
    --to=lvivier@redhat.com \
    --cc=david@gibson.dropbear.id.au \
    --cc=passt-dev@passt.top \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://passt.top/passt

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for IMAP folder(s).